@@ -76,7 +76,7 @@ public:
 };
 
 /**
- * A fake server used for testing. Losely based on KIMAP::FakeServer
+ * A fake server used for testing. Loosely based on KIMAP::FakeServer
  */
 class FakeAkonadiServer : public AkonadiServer
 {
@@ -93,8 +93,6 @@ public:
     /* Reimpl */
     bool quit();
 
-    FakeDataStore *dataStore() const;
-
     static QString basePath();
     static QString socketFile();
     static QString instanceName();
